@@ -1,5 +1,5 @@
 package PAR;
-$PAR::VERSION = '1.006';
+$PAR::VERSION = '1.008';
 
 use 5.006;
 use strict;
@@ -384,7 +384,7 @@ sub import {
         # XXX - handle META.yml here!
         push @PAR_INC, unpar($progname, undef, undef, 1);
 
-        _extract_inc($progname) unless $ENV{PAR_CLEAN};
+        _extract_inc($progname);
         if ($LibCache{$progname}) {
           # XXX bad: this us just a good guess
           require File::Spec;
@@ -494,7 +494,7 @@ sub _import_hash_ref {
         PAR::Heavy::_init_dynaloader();
         
         # XXX - handle META.yml here!
-        _extract_inc($opt->{file}) unless $ENV{PAR_CLEAN};
+        _extract_inc($opt->{file});
         
         my $zip = $LibCache{$opt->{file}};
         my $member = _first_member( $zip,
@@ -722,14 +722,9 @@ sub _extract_inc {
 
           for ( $zip->memberNames() ) {
               s{^/}{};
-
-              # Skip DLLs (these will be handled by the dynaloader hook) 
-              # except for those placed in File::ShareDir directories.
-              next if (m{\.\Q$dlext\E[^/]*$} && !m{^lib/auto/share/(dist|module)/}); 
-
               my $outfile =  File::Spec->catfile($inc, $_);
               next if -e $outfile and not -w _;
-              $zip->extractMember($_, "$inc/" . $_);
+              $zip->extractMember($_, $outfile);
           }
         }
         
@@ -793,7 +788,7 @@ sub find_par {
 
     return $rv if defined $rv or not @PriorityRepositoryObjects;
 
-    # the repositories that are prefered over locally installed modules
+    # the repositories that are preferred over locally installed modules
     my $module = $args[1];
     $module =~ s/\.pm$//;
     $module =~ s/\//::/g;
